Changelog
=========

0.2.1 (2022-01-11)
------------------

- Fix layers in adapters.
  [cekk]

0.2.0 (2022-01-11)
------------------

- Add facebook script manually (copied from original chefcookie script).
  [cekk]
- Allow to handle social based on link/script like twitter timeline
  [lucabel]


0.1.3 (2022-01-10)
------------------

- Remove YouTube unused field.
  [cekk]


0.1.2 (2022-01-10)
------------------

- Fix accept_iframe loading.
  [cekk]

0.1.1 (2022-01-10)
------------------

- Fix domain names when saving cookie settings.
  [cekk]


0.1.0 (2022-01-10)
------------------

- Initial release.
  [cekk, lucabel]
